@@ -9,8 +9,8 @@
 #' @param mapping The aesthetic mapping, usually constructed with
 #'   \code{\link[ggplot2]{aes}} or \code{\link[ggplot2]{aes_}}. Only needs to be
 #'   set at the layer level if you are overriding the plot defaults.
-#' @param data A layer specific dataset, only needed if you want to override
-#'   the plot defaults.
+#' @param data A layer specific dataset, only needed if you want to override the
+#'   plot defaults.
 #' @param geom The geometric object to use display the data
 #' @param position The position adjustment to use for overlapping points on this
 #'   layer
@@ -30,24 +30,30 @@
 #' @param alternative character One of "two.sided", "less" or "greater".
 #' @param exact logical Whether an exact p-value should be computed. Used for
 #'   Kendall's tau and Spearman's rho.
-#' @param conf.level numeric Confidence level for the returned confidence
-#'   interval (only if \code{method = "pearson"} which is the default).
+#' @param r.conf.level numeric Confidence level for the returned confidence
+#'   interval.
 #' @param continuity logical If TRUE , a continuity correction is used for
 #'   Kendall's tau and Spearman's rho when not computed exactly.
 #' @param small.r,small.p logical Flags to switch use of lower case r and p for
-#'   coefficient of correlation (only for \code{method = "pearson"}) and p-value.
+#'   coefficient of correlation (only for \code{method = "pearson"}) and
+#'   p-value.
 #' @param coef.keep.zeros logical Keep or drop trailing zeros when formatting
-#'   the correlation coefficients and t-value, z-value or S-value (see note below).
-#' @param r.digits,t.digits,p.digits integer Number of digits after the decimal point to
-#'   use for R, r.squared, tau or rho and P-value in labels.
+#'   the correlation coefficients and t-value, z-value or S-value (see note
+#'   below).
+#' @param r.digits,t.digits,p.digits integer Number of digits after the decimal
+#'   point to use for R, r.squared, tau or rho and P-value in labels.
+#' @param CI.brackets character vector of length 2. The opening and closing
+#'   brackets used for the CI label.
 #' @param label.x,label.y \code{numeric} with range 0..1 "normalized parent
 #'   coordinates" (npc units) or character if using \code{geom_text_npc()} or
 #'   \code{geom_label_npc()}. If using \code{geom_text()} or \code{geom_label()}
 #'   numeric in native data units. If too short they will be recycled.
 #' @param hstep,vstep numeric in npc units, the horizontal and vertical step
 #'   used between labels for different groups.
-#' @param output.type character One of "expression", "LaTeX", "text",
-#'   "markdown" or "numeric".
+#' @param output.type character One of "expression", "LaTeX", "text", "markdown"
+#'   or "numeric".
+#' @param boot.R interger The number of bootstrap resamples. Set to zero for no
+#'   bootstrap estimates for the CI.
 #' @param parse logical Passed to the geom. If \code{TRUE}, the labels will be
 #'   parsed into expressions and displayed as described in \code{?plotmath}.
 #'   Default is \code{TRUE} if \code{output.type = "expression"} and
@@ -60,7 +66,8 @@
 #'   device), markdown (use package 'ggtext') and plain text are also supported,
 #'   as well as numeric values for user-generated text labels. The character
 #'   labels include the symbol describing the quantity together with the numeric
-#'   value.
+#'   value. For the confidence interval (CI) the default is to follow the APA
+#'   recommendation of using square brackets.
 #'
 #'   The value of \code{parse} is set automatically based on \code{output-type},
 #'   but if you assemble labels that need parsing from \code{numeric} output,
@@ -85,10 +92,14 @@
 #' \describe{
 #'   \item{x,npcx}{x position}
 #'   \item{y,npcy}{y position}
-#'   \item{cor, tau or rho}{numeric values for correlation coefficient estimates}
+#'   \item{r, and cor, tau or rho}{numeric values for correlation coefficient estimates}
 #'   \item{t.value and its df, z.value or S.value }{numeric values for statistic estimates}
-#'   \item{p.value, n}{numeric values}
+#'   \item{p.value, n}{numeric values.}
+#'   \item{r.conf.level}{numeric value, as fraction of one.}
+#'   \item{r.confint.low}{Confidence interval limit for \code{r}.}
+#'   \item{r.confint.high}{Confidence interval limit for \code{r}.}
 #'   \item{grp.label}{Set according to mapping in \code{aes}.}
+#'   \item{method.label}{Set according \code{method} used.}
 #'   \item{method, test}{character values}}
 #'
 #' If output.type different from \code{"numeric"} the returned tibble contains
@@ -99,6 +110,7 @@
 #'   \item{r.label, and cor.label, tau.label or rho.label}{Correlation coefficient as a character string.}
 #'   \item{t.value.label, z.value.label or S.value.label}{t-value and degrees of freedom, z-value or S-value as a character string.}
 #'   \item{p.value.label}{P-value for test against zero, as a character string.}
+#'   \item{r.confint.label, and cor.conint.label, tau.confint.label or rho.confint.label}{Confidence interval for \code{r} (only with \code{method = "pearson"}).}
 #'   \item{n.label}{Number of observations used in the fit, as a character string.}
 #'   \item{grp.label}{Set according to mapping in \code{aes}, as a character string.}}
 #'
@@ -121,33 +133,20 @@
 #'                       y.desc = - y,
 #'                       group = c("A", "B"))
 #'
+#' # by default only R is displayed
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   stat_correlation()
 #'
-#' ggplot(my.data, aes(x, y.desc)) +
-#'   geom_point() +
-#'   stat_correlation(label.x = "right")
-#'
-#' ggplot(my.data, aes(x, y)) +
-#'   geom_point() +
-#'   stat_correlation(aes(label = paste(after_stat(r.label),
-#'                               after_stat(p.value.label),
-#'                               after_stat(n.label),
-#'                               sep = "*\"; \"*")))
-#'
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   stat_correlation(small.r = TRUE)
 #'
-#' ggplot(my.data, aes(x, y)) +
+#' ggplot(my.data, aes(x, y.desc)) +
 #'   geom_point() +
-#'   stat_correlation(aes(label = paste(after_stat(r.label),
-#'                               after_stat(p.value.label),
-#'                               after_stat(n.label),
-#'                               sep = "*\"; \"*")),
-#'             method = "kendall")
+#'   stat_correlation(label.x = "right")
 #'
+#' # non-default methods
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   stat_correlation(method = "kendall")
@@ -156,13 +155,47 @@
 #'   geom_point() +
 #'   stat_correlation(method = "spearman")
 #'
+#' # use_label() can map a user selected label
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   stat_correlation(use_label("R2"))
+#'
+#' # use_label() can assemble and map a combined label
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   stat_correlation(use_label(c("R", "P", "n", "method")))
+#'
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   stat_correlation(use_label(c("R", "R.CI")))
+#'
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   stat_correlation(use_label(c("R", "R.CI")), boot.R = 999)
+#'
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   stat_correlation(use_label(c("R", "R.CI")), method = "kendall")
+#'
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   stat_correlation(use_label(c("R", "R.CI")), method = "spearman")
+#'
+#' # manually assemble and map a specific label using paste() and aes()
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   stat_correlation(aes(label = paste(after_stat(r.label),
-#'                               after_stat(p.value.label),
-#'                               after_stat(n.label),
-#'                               sep = "*\"; \"*")),
-#'             method = "spearman")
+#'                                      after_stat(p.value.label),
+#'                                      after_stat(n.label),
+#'                                      sep = "*\", \"*")))
+#'
+#' # manually format and map a specific label using sprintf() and aes()
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_point() +
+#'   stat_correlation(aes(label = sprintf("%s*\" with \"*%s*\" for \"*%s",
+#'                                        after_stat(r.label),
+#'                                        after_stat(p.value.label),
+#'                                        after_stat(t.value.label))))
 #'
 #' # Inspecting the returned data using geom_debug()
 #' if (requireNamespace("gginnards", quietly = TRUE)) {
@@ -214,7 +247,7 @@ stat_correlation <- function(mapping = NULL,
                       method = "pearson",
                       alternative = "two.sided",
                       exact = NULL,
-                      conf.level = 0.95,
+                      r.conf.level = 0.95,
                       continuity = FALSE,
                       small.r = FALSE,
                       small.p = FALSE,
@@ -222,11 +255,13 @@ stat_correlation <- function(mapping = NULL,
                       r.digits = 2,
                       t.digits = 3,
                       p.digits = 3,
+                      CI.brackets = c("[", "]"),
                       label.x = "left",
                       label.y = "top",
                       hstep = 0,
                       vstep = NULL,
                       output.type = NULL,
+                      boot.R = ifelse(method == "pearson", 0, 999),
                       na.rm = FALSE,
                       parse = NULL,
                       show.legend = FALSE,
@@ -253,7 +288,7 @@ stat_correlation <- function(mapping = NULL,
     params = list(method = method,
                   alternative = alternative,
                   exact = exact,
-                  conf.level = conf.level,
+                  conf.level = r.conf.level,
                   continuity = continuity,
                   small.r = small.r,
                   small.p = small.p,
@@ -261,6 +296,7 @@ stat_correlation <- function(mapping = NULL,
                   r.digits = r.digits,
                   t.digits = t.digits,
                   p.digits = p.digits,
+                  CI.brackets = CI.brackets,
                   label.x = label.x,
                   label.y = label.y,
                   hstep = hstep,
@@ -271,6 +307,7 @@ stat_correlation <- function(mapping = NULL,
                                  vstep),
                   npc.used = grepl("_npc", geom),
                   output.type = output.type,
+                  boot.R = boot.R,
                   na.rm = na.rm,
                   parse = parse,
                   ...)
@@ -297,13 +334,20 @@ cor_test_compute_fun <- function(data,
                                  r.digits,
                                  t.digits,
                                  p.digits,
+                                 CI.brackets,
                                  label.x,
                                  label.y,
                                  hstep,
                                  vstep,
                                  npc.used,
                                  output.type,
+                                 boot.R,
                                  na.rm) {
+  # Much of the complexity of the label formatting is needed to
+  # prevent the automatic dropping of trailing zeros in expressions.
+  # The approach used is to include formatted numbers as character
+  # strings within expressions, which is very cumbersome.
+
   force(data)
 
   formula = ~ y + x
@@ -314,13 +358,14 @@ cor_test_compute_fun <- function(data,
 
   if (exists("grp.label", data)) {
     if (length(unique(data[["grp.label"]])) > 1L) {
-      warning("Non-unique value in 'data$grp.label' for group.")
-      grp.label <- ""
+      warning("Non-unique value in 'data$grp.label' using group index ", data[["group"]][1], " as label.")
+      grp.label <- as.character(data[["group"]][1])
     } else {
       grp.label <- data[["grp.label"]][1]
     }
   } else {
-    grp.label <- ""
+    # if nothing mapped to grp.label we use group index as label
+    grp.label <- as.character(data[["group"]][1])
   }
 
   group.idx <- abs(data$group[1])
@@ -361,14 +406,37 @@ cor_test_compute_fun <- function(data,
 
   z <- htest.ls[names(idx.map[[method]])]
   names(z) <- unname(idx.map[[method]])
+
   z <- tibble::as_tibble_row(z)
+
   z[["n"]] <- nrow(na.omit(data[ , c("x", "y")]))
   z[["method"]] <- method
-  # if (method == "pearson") {
-  #   z[["conf.level"]] <- conf.level
-  # }
+  z[["r.conf.level"]] <- conf.level
+  if (boot.R >= 50) {
+    confint.boot <-
+      confintr::ci_cor(data[ , c("x", "y")],
+                       probs = ((1 - conf.level) / 2) * c(1, -1) + c(0, 1),
+                       method = method,
+                       type = "bootstrap",
+                       R = boot.R)
+    z[["r.confint.low"]]  <- confint.boot[["interval"]][1]
+    z[["r.confint.high"]] <- confint.boot[["interval"]][2]
+  } else {
+    if (boot.R > 0) {
+      warning("Skipping bootstrap estimation as boot.R < 50")
+    }
+    if (method == "pearson") {
+      z[["r.confint.low"]]  <-  htest.ls[["conf.int"]][1]
+      z[["r.confint.high"]] <-  htest.ls[["conf.int"]][2]
+    } else {
+      z[["r.confint.low"]]  <- NA_real_
+      z[["r.confint.high"]] <- NA_real_
+    }
+  }
 
-  if (output.type != "numeric") {
+  if (output.type == "numeric") {
+    z[["r.label"]] <- NA_character_
+  } else {
     # warn if too narrow formats requested
     stopifnot(r.digits > 0)
     if (r.digits < 2) {
@@ -385,9 +453,20 @@ cor_test_compute_fun <- function(data,
 
     # build the character strings
     if (output.type == "expression") {
+      p.value.char <- sprintf("\"%#.*f\"", p.digits, z[["p.value"]])
       r <- z[[unname(c(pearson = "cor", kendall = "tau", spearman = "rho")[method])]]
       r.char <- sprintf("\"%#.*f\"", r.digits, r)
+      r.confint.chr <- sprintf("%#.*f, %#.*f",
+                               r.digits, z[["r.confint.low"]],
+                               r.digits, z[["r.confint.high"]])
+      if (as.logical((z[["r.conf.level"]] * 100) %% 1)) {
+        conf.level.digits = 1L
+      } else {
+        conf.level.digits = 0L
+      }
+      conf.level.chr <- sprintf("%.*f", conf.level.digits, z[["r.conf.level"]] * 100)
       if (method == "pearson") {
+        rr.char <- sprintf("\"%#.*f\"", r.digits, r^2)
         t.value.char <- sprintf("\"%#.*g\"", t.digits, z[["t.value"]])
         df.char <- as.character(z[["df"]])
       } else if (method == "kendall") {
@@ -395,11 +474,21 @@ cor_test_compute_fun <- function(data,
       } else if (method == "spearman") {
         S.value.char <- sprintf("\"%#.*g\"", t.digits, z[["S.value"]])
       }
-      p.value.char <- sprintf("\"%#.*f\"", p.digits, z[["p.value"]])
     } else {
+      p.value.char <- sprintf("%#.*f", p.digits, z[["p.value"]])
       r <- z[[unname(c(pearson = "cor", kendall = "tau", spearman = "rho")[method])]]
       r.char <- sprintf("%#.*f", r.digits, r)
+      r.confint.chr <- sprintf("%#.*f, %#.*f",
+                               r.digits, z[["conf.int.low"]],
+                               r.digits, z[["conf.int.high"]])
+      if (as.logical((z[["r.conf.level"]] * 100) %% 1)) {
+        conf.level.digits = 1L
+      } else {
+        conf.level.digits = 0L
+      }
+      conf.level.chr <- sprintf("%.*f", conf.level.digits, z[["r.conf.level"]] * 100)
       if (method == "pearson") {
+        rr.char <- sprintf("\"%#.*f\"", r.digits, r^2)
         t.value.char <- sprintf("%#.*g", t.digits, z[["t.value"]])
         df.char <- as.character(z[["df"]])
       } else if (method == "kendall") {
@@ -407,12 +496,10 @@ cor_test_compute_fun <- function(data,
       } else if (method == "spearman") {
         S.value.char <- sprintf("%#.*g", t.digits, z[["S.value"]])
       }
-      p.value.char <- sprintf("%#.*f", p.digits, z[["p.value"]])
     }
 
     # add labels to data.frame z.labels
     if (output.type == "expression") {
-
       # character(0) instead of "" avoids in paste() the insertion of sep for missing labels
       z[["p.value.label"]] <-
         ifelse(is.na(z[["p.value"]]), character(0L),
@@ -427,7 +514,7 @@ cor_test_compute_fun <- function(data,
         paste("italic(n)~`=`~\"", z[["n"]], "\"", sep = "")
       z[["grp.label"]] <- grp.label
       if (method == "pearson") {
-        z[["cor.label"]] <-
+        z[["cor.label"]] <- z[["r.label"]] <-
           ifelse(is.na(z[["cor"]]), character(0L),
                  paste(ifelse(small.r, "italic(r)", "italic(R)"),
                        ifelse(abs(z[["cor"]]) < 10^(-r.digits),
@@ -436,11 +523,21 @@ cor_test_compute_fun <- function(data,
                        sep = ifelse(abs(z[["cor"]]) < 10^(-r.digits),
                                     c("~`>`~", "~`=`~", "~`<`~")[sign(z[["cor"]]) + 2],
                                     "~`=`~")))
+        z[["rr.label"]] <-
+           paste(ifelse(small.r, "italic(r)^2", "italic(R)^2"),
+                ifelse(r^2 < 10^(-r.digits) & r^2 != 0,
+                       sprintf("\"%.*f\"", r.digits, 10^(-r.digits)),
+                       rr.char),
+                sep = ifelse(r^2 < 10^(-r.digits) & r^2 != 0,
+                             "~`<`~",
+                             "~`=`~"))
         z[["t.value.label"]] <-
           ifelse(is.na(z[["t.value"]]), character(0L),
                  paste("italic(t)[", df.char, "]~`=`~", t.value.char, sep = ""))
+        z[["r.confint.label"]] <- z[["cor.confint.label"]] <-
+          paste("\"", conf.level.chr, "% CI ", CI.brackets[1], r.confint.chr, CI.brackets[2], "\"", sep = "")
       } else if (method == "kendall") {
-        z[["tau.label"]] <-
+        z[["tau.label"]] <- z[["r.label"]] <-
           ifelse(is.na(z[["tau"]]), character(0L),
                  paste("italic(tau)",
                        ifelse(abs(z[["tau"]]) < 10^(-r.digits),
@@ -452,8 +549,10 @@ cor_test_compute_fun <- function(data,
         z[["z.value.label"]] <-
           ifelse(is.na(z[["z.value"]]), character(0L),
                  paste("italic(z)~`=`~", z.value.char, sep = ""))
+        z[["r.confint.label"]] <- z[["tau.confint.label"]] <-
+          paste("\"", conf.level.chr, "% CI ", CI.brackets[1], r.confint.chr, CI.brackets[2], "\"", sep = "")
       } else if (method == "spearman") {
-        z[["rho.label"]] <-
+        z[["rho.label"]] <- z[["r.label"]] <-
           ifelse(is.na(z[["rho"]]), character(0L),
                  paste("italic(rho)",
                        ifelse(abs(z[["rho"]]) < 10^(-r.digits),
@@ -465,9 +564,12 @@ cor_test_compute_fun <- function(data,
         z[["S.value.label"]] <-
           ifelse(is.na(z[["S.value"]]), character(0L),
                  paste("italic(S)~`=`~", S.value.char, sep = ""))
+        z[["r.confint.label"]] <- z[["rho.confint.label"]] <-
+          paste("\"", conf.level.chr, "% CI ", CI.brackets[1], r.confint.chr, CI.brackets[2], "\"", sep = "")
       }
+      z[["method.label"]] <-
+        paste("\"method: ", method, "\"", sep = "")
     } else if (output.type %in% c("latex", "tex", "text", "tikz")) {
-      # character(0) instead of "" avoids in paste() the insertion of sep for missing labels
       z[["p.value.label"]] <-
         ifelse(is.na(z[["p.value"]]), character(0L),
                paste(ifelse(small.p, "p",  "P"),
@@ -481,7 +583,7 @@ cor_test_compute_fun <- function(data,
         paste("n = ", z[["n"]], sep = "")
       z[["grp.label"]] <- grp.label
       if (method == "pearson") {
-        z[["cor.label"]] <-
+        z[["cor.label"]] <- z[["r.label"]] <-
           ifelse(is.na(z[["cor"]]), character(0L),
                  paste(ifelse(small.r, "r", "R"),
                        ifelse(abs(z[["cor"]]) < 10^(-r.digits),
@@ -490,33 +592,50 @@ cor_test_compute_fun <- function(data,
                        sep = ifelse(abs(z[["cor"]]) < 10^(-r.digits),
                                     c(" > ", " = ", " < ")[sign(z[["cor"]]) + 2],
                                     " = ")))
+        z[["rr.label"]] <-
+          paste(ifelse(small.r, "italic(r)^2", "italic(R)^2"),
+                ifelse(r^2 < 10^(-r.digits) & r^2 != 0,
+                       sprintf("\"%.*f\"", r.digits, 10^(-r.digits)),
+                       rr.char),
+                sep = ifelse(r^2 < 10^(-r.digits) & r^2 != 0,
+                             "~`<`~",
+                             "~`=`~"))
         z[["t.value.label"]] <- ifelse(is.na(z[["t.value"]]), character(0L),
                                        paste("t_{", df.char, "} = ", t.value.char, sep = ""))
+        z[["r.confint.label"]] <- z[["cor.confint.label"]] <-
+          paste(conf.level.chr, "% CI ", CI.brackets[1], r.confint.chr, CI.brackets[2], sep = "")
       } else if (method == "kendall") {
-        z[["tau.label"]] <- ifelse(is.na(z[["tau"]]), character(0L),
-                                   paste(ifelse(output.type == "text",
-                                                "tau", "\tau"),
-                                         ifelse(abs(z[["tau"]]) < 10^(-r.digits),
-                                                sprintf("\"%.*f\"", r.digits, 10^(-r.digits) * sign(z[["tau"]])),
-                                                r.char),
-                                         sep = ifelse(abs(z[["tau"]]) < 10^(-r.digits),
-                                                      c(" > ", " = ", " < ")[sign(z[["tau"]]) + 2],
-                                                      " = ")))
+        z[["tau.label"]] <- z[["r.label"]] <-
+          ifelse(is.na(z[["tau"]]), character(0L),
+                 paste(ifelse(output.type == "text",
+                              "tau", "\tau"),
+                       ifelse(abs(z[["tau"]]) < 10^(-r.digits),
+                              sprintf("\"%.*f\"", r.digits, 10^(-r.digits) * sign(z[["tau"]])),
+                              r.char),
+                       sep = ifelse(abs(z[["tau"]]) < 10^(-r.digits),
+                                    c(" > ", " = ", " < ")[sign(z[["tau"]]) + 2],
+                                    " = ")))
         z[["z.value.label"]] <- ifelse(is.na(z[["z.value"]]), character(0L),
                                        paste("z = ", z.value.char, sep = ""))
+        z[["r.confint.label"]] <- z[["tau.confint.label"]] <-
+          paste(conf.level.chr, "% CI ", CI.brackets[1], r.confint.chr, CI.brackets[2], sep = "")
       } else if (method == "spearman") {
-        z[["rho.label"]] <- ifelse(is.na(z[["rho"]]), character(0L),
-                                   paste(ifelse(output.type == "text",
-                                                "rho", "\rho"),
-                                         ifelse(abs(z[["rho"]]) < 10^(-r.digits),
-                                                sprintf("\"%.*f\"", r.digits, 10^(-r.digits) * sign(z[["rho"]])),
-                                                r.char),
-                                         sep = ifelse(abs(z[["rho"]]) < 10^(-r.digits),
-                                                      c(" > ", " = ", " < ")[sign(z[["rho"]]) + 2],
-                                                      " = ")))
+        z[["rho.label"]] <- z[["r.label"]] <-
+          ifelse(is.na(z[["rho"]]), character(0L),
+                 paste(ifelse(output.type == "text",
+                              "rho", "\rho"),
+                       ifelse(abs(z[["rho"]]) < 10^(-r.digits),
+                              sprintf("\"%.*f\"", r.digits, 10^(-r.digits) * sign(z[["rho"]])),
+                              r.char),
+                       sep = ifelse(abs(z[["rho"]]) < 10^(-r.digits),
+                                    c(" > ", " = ", " < ")[sign(z[["rho"]]) + 2],
+                                    " = ")))
         z[["S.value.label"]] <- ifelse(is.na(z[["S.value"]]), character(0L),
                                        paste("S = ", S.value.char, sep = ""))
+        z[["r.confint.label"]] <- z[["rho.confint.label"]] <-
+          paste(conf.level.chr, "% CI ", CI.brackets[1], r.confint.chr, CI.brackets[2], sep = "")
       }
+      z[["method.label"]] <- paste("method: ", method, sep = "")
     } else if (output.type == "markdown") {
       z[["p.value.label"]] <-
         ifelse(is.na(z[["p.value"]]), character(0L),
@@ -531,7 +650,7 @@ cor_test_compute_fun <- function(data,
         paste("_n_ = ", z[["n"]], sep = "")
       z[["grp.label"]] <- grp.label
       if (method == "pearson") {
-        z[["cor.label"]] <-
+        z[["cor.label"]] <- z[["r.label"]] <-
           ifelse(is.na(z[["cor"]]), character(0L),
                  paste(ifelse(small.r, "_r_", "_R_"),
                        ifelse(abs(z[["cor"]]) < 10^(-r.digits),
@@ -540,42 +659,53 @@ cor_test_compute_fun <- function(data,
                        sep = ifelse(abs(z[["cor"]]) < 10^(-r.digits),
                                     c(" > ", " = ", " < ")[sign(z[["cor"]]) + 2],
                                     " = ")))
+        z[["rr.label"]] <-
+          paste(ifelse(small.r, "_r_<sup>2</sup>", "_R_<sup>2</sup>"),
+                ifelse(r^2 < 10^(-r.digits) & r^2 != 0,
+                       sprintf("\"%.*f\"", r.digits, 10^(-r.digits)),
+                       rr.char),
+                sep = ifelse(r^2 < 10^(-r.digits) & r^2 != 0,
+                             " < ",
+                             " = "))
         z[["t.value.label"]] <- ifelse(is.na(z[["t.value"]]), character(0L),
                                        paste("_t_<sub>", df.char, "</sub> = ", t.value.char, sep = ""))
+        z[["r.confint.label"]] <- z[["cor.confint.label"]] <-
+          paste(conf.level.chr, "% CI ", CI.brackets[1], r.confint.chr, CI.brackets[1], sep = "")
       } else if (method == "kendall") {
-        z[["tau.label"]] <- ifelse(is.na(z[["tau"]]), character(0L),
-                                   paste("_&tau;_",
-                                         ifelse(abs(z[["tau"]]) < 10^(-r.digits),
-                                                sprintf("\"%.*f\"", r.digits, 10^(-r.digits) * sign(z[["tau"]])),
-                                                r.char),
-                                         sep = ifelse(abs(z[["tau"]]) < 10^(-r.digits),
-                                                      c(" > ", " = ", " < ")[sign(z[["tau"]]) + 2],
-                                                      " = ")))
+        z[["tau.label"]] <- z[["r.label"]] <-
+          ifelse(is.na(z[["tau"]]), character(0L),
+                 paste("_&tau;_",
+                       ifelse(abs(z[["tau"]]) < 10^(-r.digits),
+                              sprintf("\"%.*f\"", r.digits, 10^(-r.digits) * sign(z[["tau"]])),
+                              r.char),
+                       sep = ifelse(abs(z[["tau"]]) < 10^(-r.digits),
+                                    c(" > ", " = ", " < ")[sign(z[["tau"]]) + 2],
+                                    " = ")))
         z[["z.value.label"]] <- ifelse(is.na(z[["t.value"]]), character(0L),
                                        paste("_z_ = ", z.value.char, sep = ""))
+        z[["r.confint.label"]] <- z[["tau.confint.label"]] <-
+          paste(conf.level.chr, "% CI ", CI.brackets[1], r.confint.chr, CI.brackets[2], sep = "")
       } else if (method == "spearman") {
-        z[["rho.label"]] <- ifelse(is.na(z[["rho"]]), character(0L),
-                                   paste("_&rho;_",
-                                         ifelse(abs(z[["rho"]]) < 10^(-r.digits),
-                                                sprintf("\"%.*f\"", r.digits, 10^(-r.digits) * sign(z[["rho"]])),
-                                                r.char),
-                                         sep = ifelse(abs(z[["rho"]]) < 10^(-r.digits),
-                                                      c(" > ", " = ", " < ")[sign(z[["rho"]]) + 2],
-                                                      " = ")))
+        z[["rho.label"]] <- z[["r.label"]] <-
+          ifelse(is.na(z[["rho"]]), character(0L),
+                 paste("_&rho;_",
+                       ifelse(abs(z[["rho"]]) < 10^(-r.digits),
+                              sprintf("\"%.*f\"", r.digits, 10^(-r.digits) * sign(z[["rho"]])),
+                              r.char),
+                       sep = ifelse(abs(z[["rho"]]) < 10^(-r.digits),
+                                    c(" > ", " = ", " < ")[sign(z[["rho"]]) + 2],
+                                    " = ")))
         z[["S.value.label"]] <- ifelse(is.na(z[["S.value"]]), character(0L),
                                        paste("_S_ = ", S.value.char, sep = ""))
+        z[["r.confint.label"]] <- z[["rho.confint.label"]] <-
+          paste(conf.level.chr, "% CI ", CI.brackets[1], r.confint.chr, CI.brackets[2], sep = "")
       }
+      z[["method.label"]] <- paste("method: ", method, sep = "")
     } else {
       warning("Unknown 'output.type' argument: ", output.type)
     }
   }
 
-  # set column to map by default to label
-  z[["r.label"]] <- switch(method,
-                           pearson =  z[["cor.label"]],
-                           kendall =  z[["tau.label"]],
-                           spearman = z[["rho.label"]])
-
   # Compute label positions
   if (is.character(label.x)) {
     if (npc.used) {
@@ -636,6 +766,8 @@ StatCorr <-
                      ggplot2::aes(npcx = after_stat(npcx),
                                   npcy = after_stat(npcy),
                                   label = after_stat(r.label),
-                                  hjust = "inward", vjust = "inward"),
-                   required_aes = c("x", "y")
+                                  hjust = "inward",
+                                  vjust = "inward"),
+                   required_aes = c("x", "y"),
+                   optional_aes = "grp.label"
   )
