@@ -48,8 +48,8 @@
 #'   the fitted coefficients.
 #' @param coef.keep.zeros logical Keep or drop trailing zeros when formatting
 #'   the fitted coefficients and F-value.
-#' @param rr.digits,p.digits integer Number of digits after the decimal point to
-#'   use for R^2 and P-value in labels.
+#' @param rr.digits,p.digits,theta.digits integer Number of digits after the
+#'   decimal point to use for R^2, theta and P-value in labels.
 #' @param label.x,label.y \code{numeric} with range 0..1 "normalized parent
 #'   coordinates" (npc units) or character if using \code{geom_text_npc()} or
 #'   \code{geom_label_npc()}. If using \code{geom_text()} or \code{geom_label()}
@@ -83,14 +83,18 @@
 #'   passed as a character string together with the \code{lmodel2}-supported
 #'   method.
 #'
-#' @details This stat can be used to automatically annotate a plot with R^2,
-#'   P_value, n and/or the fitted model equation. It supports linear major axis
+#' @details This stat can be used to automatically annotate a plot with \eqn{R^2},
+#'   \eqn{P}-value, \eqn{n} and/or the fitted model equation. It supports linear major axis
 #'   (MA), standard major axis (SMA) and ranged major axis (RMA) regression by
 #'   means of function \code{\link[lmodel2]{lmodel2}}. Please see the
 #'   documentation, including the vignette of package 'lmodel2' for details.
 #'   The parameters in \code{stat_ma_eq()} follow the same naming as in function
 #'   \code{lmodel2()}.
 #'
+#'   It is important to keep in mind that although the fitted line does not
+#'   depend on whether the \eqn{x} or \eqn{y} appears on the rhs of the model
+#'   formula, the numeric estimates for the parameters do depend on this.
+#'
 #'   A ggplot statistic receives as \code{data} a data frame that is not the one
 #'   passed as argument by the user, but instead a data frame with the variables
 #'   mapped to aesthetics. \code{stat_ma_eq()} mimics how \code{stat_smooth()}
@@ -113,10 +117,12 @@
 #'   \item{y,npcy}{y position}
 #'   \item{eq.label}{equation for the fitted polynomial as a character string to be parsed}
 #'   \item{rr.label}{\eqn{R^2} of the fitted model as a character string to be parsed}
-#'   \item{p.value.label}{P-value for the F-value above.}
+#'   \item{p.value.label}{P-value if available, depends on \code{method}.}
+#'   \item{theta.label}{Angle in degrees between the two OLS lines for lines estimated from \code{y ~ x} and \code{x ~ y} linear model (\code{lm}) fits.}
 #'   \item{n.label}{Number of observations used in the fit.}
 #'   \item{grp.label}{Set according to mapping in \code{aes}.}
-#'   \item{r.squared, p.value, n}{numeric values, from the model fit object}}
+#'   \item{method.label}{Set according \code{method} used.}
+#'   \item{r.squared, theta, p.value, n}{numeric values, from the model fit object}}
 #'
 #' If output.type is \code{"numeric"} the returned tibble contains columns
 #' listed below. If the model fit function used does not return a value,
@@ -125,7 +131,7 @@
 #'   \item{x,npcx}{x position}
 #'   \item{y,npcy}{y position}
 #'   \item{coef.ls}{list containing the "coefficients" matrix from the summary of the fit object}
-#'   \item{r.squared, adj.r.squared, f.value, f.df1, f.df2, p.value, AIC, BIC, n}{numeric values, from the model fit object}
+#'   \item{r.squared, theta, p.value, n}{numeric values, from the model fit object}
 #'   \item{grp.label}{Set according to mapping in \code{aes}.}
 #'   \item{b_0.constant}{TRUE is polynomial is forced through the origin}
 #'   \item{b_i}{One or two columns with the coefficient estimates}}
@@ -134,17 +140,16 @@
 #' of \code{\link[gginnards]{geom_debug}} as shown in the last examples below.
 #'
 #' @seealso The major axis regression model is fitted with function
-#'   \code{\link[lmodel2]{lmodel2}}, please consult its documentation. This
-#'   \code{stat_ma_eq} statistic can return ready formatted labels depending on
-#'   the argument passed to \code{output.type}. If ordinary least squares
-#'   polynomial regression is desired, then \code{\link{stat_poly_eq}}. For
-#'   quantile fits of polynomial regression is desired,
+#'   \code{\link[lmodel2]{lmodel2}}, please consult its documentation. Statistic
+#'   \code{stat_ma_eq()} can return different ready formatted labels depending
+#'   on the argument passed to \code{output.type}. If ordinary least squares
+#'   polynomial regression is desired, then \code{\link{stat_poly_eq}}. If
+#'   quantile-fitted polynomial regression is desired,
 #'   \code{\link{stat_quant_eq}} should be used. For other types of models such
 #'   as non-linear models, statistics \code{\link{stat_fit_glance}} and
 #'   \code{\link{stat_fit_tidy}} should be used and the code for construction of
 #'   character strings from numeric values and their mapping to aesthetic
-#'   \code{label} needs to be explicitly supplied
-#'   in the call.
+#'   \code{label} explicitly supplied in the call.
 #'
 #' @family ggplot statistics for major axis regression
 #'
@@ -161,55 +166,42 @@
 #'   stat_ma_line() +
 #'   stat_ma_eq()
 #'
-#' # using major axis regression
+#' # use_label() can assemble and map a combined label
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   stat_ma_line(method = "MA") +
-#'   stat_ma_eq(aes(label =
-#'     paste(after_stat(eq.label),
-#'           after_stat(p.value.label),
-#'           sep = "*\", \"*")),
-#'           method = "MA")
+#'   stat_ma_eq(use_label(c("eq", "R2", "P")))
 #'
-#' # using standard major axis regression
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
-#'   stat_ma_line(method = "SMA") +
-#'   stat_ma_eq(aes(label =
-#'     paste(after_stat(eq.label),
-#'           after_stat(p.value.label),
-#'           sep = "*\", \"*")),
-#'           method = "SMA")
+#'   stat_ma_line(method = "MA") +
+#'   stat_ma_eq(use_label(c("R2", "P", "theta", "method")))
 #'
 #' # using ranged major axis regression
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
-#'   stat_ma_line(method = "RMA", range.y = "interval", range.x = "interval") +
-#'   stat_ma_eq(aes(label =
-#'     paste(after_stat(eq.label),
-#'           after_stat(p.value.label),
-#'           sep = "*\", \"*")),
-#'           method = "RMA",
-#'           range.y = "interval", range.x = "interval")
+#'   stat_ma_line(method = "RMA",
+#'                range.y = "interval",
+#'                range.x = "interval") +
+#'   stat_ma_eq(use_label(c("eq", "R2", "P")),
+#'              method = "RMA",
+#'              range.y = "interval",
+#'              range.x = "interval")
 #'
 #' # No permutation-based test
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   stat_ma_line(method = "MA") +
-#'   stat_ma_eq(aes(label =
-#'     paste(after_stat(eq.label),
-#'           after_stat(p.value.label),
-#'           sep = "*\", \"*")),
-#'           method = "MA", nperm = 0)
+#'   stat_ma_eq(use_label(c("eq", "R2")),
+#'              method = "MA",
+#'              nperm = 0)
 #'
 #' # explicit formula "x explained by y"
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
 #'   stat_ma_line(formula = x ~ y) +
 #'   stat_ma_eq(formula = x ~ y,
-#'              aes(label = paste(after_stat(eq.label),
-#'                                after_stat(p.value.label),
-#'                                sep = "*\", \"*")))
+#'              use_label(c("eq", "R2", "P")))
 #'
 #' # grouping
 #' ggplot(my.data, aes(x, y, color = group)) +
@@ -218,21 +210,13 @@
 #'   stat_ma_eq()
 #'
 #' # labelling equations
-#' ggplot(my.data, aes(x, y,  shape = group, linetype = group,
-#'        grp.label = group)) +
+#' ggplot(my.data,
+#'        aes(x, y,  shape = group, linetype = group, grp.label = group)) +
 #'   geom_point() +
 #'   stat_ma_line(color = "black") +
-#'   stat_ma_eq(aes(label = paste(after_stat(grp.label),
-#'                                after_stat(eq.label),
-#'                                sep = "*\": \"*"))) +
+#'   stat_ma_eq(use_label(c("grp", "eq", "R2"))) +
 #'   theme_classic()
 #'
-#' # geom = "text"
-#' ggplot(my.data, aes(x, y)) +
-#'   geom_point() +
-#'   stat_ma_line() +
-#'   stat_ma_eq(label.x = "left", label.y = "top")
-#'
 #' # Inspecting the returned data using geom_debug()
 #' \dontrun{
 #' if (requireNamespace("gginnards", quietly = TRUE)) {
@@ -282,6 +266,7 @@ stat_ma_eq <- function(mapping = NULL, data = NULL,
                        coef.digits = 3,
                        coef.keep.zeros = TRUE,
                        rr.digits = 2,
+                       theta.digits = 2,
                        p.digits = max(1, ceiling(log10(nperm))),
                        label.x = "left",
                        label.y = "top",
@@ -336,6 +321,7 @@ stat_ma_eq <- function(mapping = NULL, data = NULL,
                   coef.digits = coef.digits,
                   coef.keep.zeros = coef.keep.zeros,
                   rr.digits = rr.digits,
+                  theta.digits = theta.digits,
                   p.digits = p.digits,
                   label.x = label.x,
                   label.y = label.y,
@@ -377,6 +363,7 @@ ma_eq_compute_group_fun <- function(data,
                                     coef.digits,
                                     coef.keep.zeros,
                                     rr.digits,
+                                    theta.digits,
                                     p.digits,
                                     label.x,
                                     label.y,
@@ -410,13 +397,14 @@ ma_eq_compute_group_fun <- function(data,
 
   if (exists("grp.label", data)) {
     if (length(unique(data[["grp.label"]])) > 1L) {
-    warning("Non-unique value in 'data$grp.label' for group.")
-      grp.label <- ""
+      warning("Non-unique value in 'data$grp.label' using group index ", data[["group"]][1], " as label.")
+      grp.label <- as.character(data[["group"]][1])
     } else {
       grp.label <- data[["grp.label"]][1]
     }
   } else {
-    grp.label <- ""
+    # if nothing mapped to grp.label we use group index as label
+    grp.label <- as.character(data[["group"]][1])
   }
 
   group.idx <- abs(data$group[1])
@@ -514,22 +502,24 @@ ma_eq_compute_group_fun <- function(data,
   # lmodel2 issues a warning that is irrelevant here
   # so we silence it selectively
   withCallingHandlers({
-    mf <- do.call(what = method, args = fit.args)
+    fm <- do.call(what = method, args = fit.args)
   }, message = function(w) {
     if (grepl("RMA was not requested", conditionMessage(w), fixed = TRUE)) {
       invokeRestart("muffleMessage")
     }
   })
 
-  if (!inherits(mf, "lmodel2")) {
+  if (!inherits(fm, "lmodel2")) {
     stop("Method \"", method.name, "\" did not return a \"lmodel2\" object")
   }
+  fm.class <- class(fm)
 
-  n <- mf[["n"]]
-  coefs <- stats::coefficients(mf, method = fun.method)
-  rr <- mf[["rsquare"]]
-  idx <- which(mf[["regression.results"]][["Method"]] == fun.method)
-  p.value <- mf[["regression.results"]][["P-perm (1-tailed)"]][idx]
+  n <- fm[["n"]]
+  coefs <- stats::coefficients(fm, method = fun.method)
+  rr <- fm[["rsquare"]]
+  theta <- fm[["theta"]]
+  idx <- which(fm[["regression.results"]][["Method"]] == fun.method)
+  p.value <- fm[["regression.results"]][["P-perm (1-tailed)"]][idx]
 
   formula.rhs.chr <- as.character(formula)[3]
   forced.origin <- grepl("-[[:space:]]*1|+[[:space:]]*0", formula.rhs.chr)
@@ -540,6 +530,7 @@ ma_eq_compute_group_fun <- function(data,
 
   if (output.type == "numeric") {
     z <- tibble::tibble(r.squared = rr,
+                        theta = theta,
                         p.value = p.value,
                         n = n,
                         rr.label = "",  # needed for default 'label' mapping
@@ -575,6 +566,10 @@ ma_eq_compute_group_fun <- function(data,
     if (rr.digits < 2) {
       warning("'rr.digits < 2' Likely information loss!")
     }
+    stopifnot(theta.digits > 0)
+    if (theta.digits < 2) {
+      warning("'theta.digits < 2' Likely information loss!")
+    }
     stopifnot(p.digits > 0)
     if (p.digits < 2) {
       warning("'p.digits < 2' Likely information loss!")
@@ -582,9 +577,11 @@ ma_eq_compute_group_fun <- function(data,
 
     if (output.type == "expression") {
       rr.char <- sprintf("\"%#.*f\"", rr.digits, rr)
+      theta.char <- sprintf("\"%#.*f\"", theta.digits, theta)
       p.value.char <- sprintf("\"%#.*f\"", p.digits, p.value)
     } else {
       rr.char <- sprintf("%#.*f", rr.digits, rr)
+      theta.char <- sprintf("%#.*f", theta.digits, theta)
       p.value.char <- sprintf("%#.*f", p.digits, p.value)
     }
 
@@ -610,9 +607,12 @@ ma_eq_compute_group_fun <- function(data,
                                          sep = ifelse(p.value < 10^(-p.digits),
                                                       "~`<`~",
                                                       "~`=`~"))),
+                          theta.label = paste("italic(theta)~`=`~", theta.char, sep = ""),
                           n.label = paste("italic(n)~`=`~\"", n, "\"", sep = ""),
                           grp.label = grp.label,
+                          method.label = paste("\"method: ", method.name, "\"", sep = ""),
                           r.squared = rr,
+                          theta = theta,
                           p.value = p.value,
                           n = n)
     } else if (output.type %in% c("latex", "tex", "text", "tikz")) {
@@ -628,9 +628,12 @@ ma_eq_compute_group_fun <- function(data,
                                    paste(ifelse(small.p, "p_{perm}",  "P_{perm}"),
                                          ifelse(p.value < 10^(-p.digits), as.character(10^(-p.digits)), p.value.char),
                                          sep = ifelse(p.value < 10^(-p.digits), " < ", " = "))),
-                          n.label = paste("n = ", n, sep = ""),
+                          theta.label = paste("theta", theta.char, sep = " = "),
+                          n.label = paste("n", n, sep = " = "),
                           grp.label = grp.label,
+                          method.label = paste("method: ", method.name, sep = ""),
                           r.squared = rr,
+                          theta = theta,
                           p.value = p.value,
                           n = n)
     } else if (output.type == "markdown") {
@@ -646,9 +649,12 @@ ma_eq_compute_group_fun <- function(data,
                                    paste(ifelse(small.p, "_p_<sub>perm</sub>", "_P_<sub>perm</sub>"),
                                          ifelse(p.value < 10^(-p.digits), as.character(10^(-p.digits)), p.value.char),
                                          sep = ifelse(p.value < 10^(-p.digits), " < ", " = "))),
+                          theta.label = paste("_&theta;_", theta.char, sep = " = "),
                           n.label = paste("_n_ = ", n, sep = ""),
                           grp.label = grp.label,
+                          method.label = paste("method: ", method.name, sep = ""),
                           r.squared = rr,
+                          theta = theta,
                           p.value = p.value,
                           n = n)
     } else {
@@ -656,7 +662,9 @@ ma_eq_compute_group_fun <- function(data,
     }
   }
 
-  z[["method"]] <- method.name
+  z[["fm.method"]] <- method.name
+  z[["fm.class"]] <- fm.class[1]
+  z[["fm.formula.char"]] <- format(formula)
 
   # Compute label positions
   if (is.character(label.x)) {
@@ -719,6 +727,7 @@ StatMaEq <-
                                   label = after_stat(rr.label),
                                   hjust = "inward", vjust = "inward",
                                   weight = 1),
-                   required_aes = c("x", "y")
+                   required_aes = c("x", "y"),
+                   optional_aes = "grp.label"
   )
 
