@@ -1,4 +1,4 @@
-#' Compute predicted line from quantile regression fit
+#' Predicted band from quantile regression fits
 #'
 #' Predicted values are computed and, by default, plotted as a band plus an
 #' optional line within. \code{stat_quant_band()} supports the use of both
@@ -6,7 +6,7 @@
 #'
 #' This statistic is similar to \code{\link{stat_quant_line}} but plots the
 #' quantiles differently with the band representing a region between two
-#' quantiles, while in \code{stat_quant_line()} the bands plotted whe
+#' quantiles, while in \code{stat_quant_line()} the bands plotted when
 #' \code{se = TRUE} represent confidence intervals for the fitted quantile
 #' lines.
 #'
@@ -42,26 +42,24 @@
 #'   instead of original variable names.
 #' @param quantiles numeric vector Two or three values in 0..1 indicating the
 #'   quantiles at the  edges of the band and optionally a line within the band.
-#' @param method function or character If character, "lm", "rlm" and
-#'   "rq" are accepted. If a function, it must have formal parameters
-#'   \code{formula} and \code{data} and return a model fit object for which
-#'   \code{summary()} and \code{coefficients()} are consistent with those for
-#'   \code{lm} fits.
+#' @param method function or character If character, "rq", "rqss" or the name of
+#'   a model fit function are accepted, possibly followed by the fit function's
+#'   \code{method} argument separated by a colon (e.g. \code{"rq:br"}). If a
+#'   function different to \code{rq()}, it must accept arguments named
+#'   \code{formula}, \code{data}, \code{weights}, \code{tau} and \code{method}
+#'   and return a model fit object of class \code{rq}, \code{rqs} or
+#'   \code{rqss}.
 #' @param method.args named list with additional arguments.
 #' @param n Number of points at which to evaluate smoother.
 #' @param orientation character Either "x" or "y" controlling the default for
 #'   \code{formula}.
+#' @param fm.values logical Add n as a column to returned data? (`FALSE` by
+#'   default.)
 #'
 #' @return The value returned by the statistic is a data frame, that will have
 #'   \code{n} rows of predicted values for three quantiles as \code{y},
 #'   \code{ymin} and \code{ymax}, plus \code{x}.
 #'
-#' @note Even though the \code{ggplot2::geom_smooth()} is used by default, the
-#'   default colour of the band is different to avoid confusion of between
-#'   quantile bands and confidence bands. Of course, the \code{fill} aesthtics
-#'   can be mapped to a variable or to a constant as usual
-#'   (\code{fill = "grey60"} restores the geom's original default).
-#'
 #' @section Aesthetics: \code{stat_quant_eq} expects \code{x} and \code{y},
 #'   aesthetics to be used in the \code{formula} rather than the names of the
 #'   variables mapped to them. If present, the variable mapped to the
@@ -137,6 +135,18 @@
 #'   stat_quant_band(quantiles = c(0, 0.1, 0.2)) +
 #'   geom_point()
 #'
+#' # Inspecting the returned data using geom_debug()
+#' if (requireNamespace("gginnards", quietly = TRUE)) {
+#'   library(gginnards)
+#'
+#'   ggplot(mpg, aes(displ, hwy)) +
+#'     stat_quant_band(geom = "debug")
+#'
+#'   ggplot(mpg, aes(displ, hwy)) +
+#'     stat_quant_band(geom = "debug", fm.values = TRUE)
+#'
+##' }
+#'
 #' @export
 #'
 stat_quant_band <- function(mapping = NULL,
@@ -146,6 +156,7 @@ stat_quant_band <- function(mapping = NULL,
                             ...,
                             quantiles = c(0.25, 0.5, 0.75),
                             formula = NULL,
+                            fm.values = FALSE,
                             n = 80,
                             method = "rq",
                             method.args = list(),
@@ -179,6 +190,13 @@ stat_quant_band <- function(mapping = NULL,
            "the formula should have 'x' as explanatory variable.")
     }
   }
+  if (is.character(method)) {
+    if (grepl("^lm|^rlm", method)) {
+      stop("Methods 'lm' and 'rlm' not supported, please use 'stat_poly_eq()'.")
+    } else if (grepl("^lmodel2", method)) {
+      stop("Method 'lmodel2' not supported, please use 'stat_ma_eq()'.")
+    }
+  }
 
   ggplot2::layer(
     data = data,
@@ -191,6 +209,7 @@ stat_quant_band <- function(mapping = NULL,
     params = list(
       quantiles = quantiles,
       formula = formula,
+      fm.values = fm.values,
       n = n,
       method = method,
       method.args = method.args,
@@ -214,12 +233,13 @@ quant_band_compute_group_fun <- function(data,
                                          quantiles = c(0.25, 0.5, 0.75),
                                          formula = NULL,
                                          n = 80,
-                                         method = "rq",
+                                         method = "rq:br",
                                          method.args = list(),
                                          lambda = 1,
+                                         fm.values = FALSE,
                                          na.rm = FALSE,
                                          flipped_aes = NA) {
-  rlang::check_installed("quantreg", reason = "for `stat_quantile()`")
+  rlang::check_installed("quantreg", reason = "for `stat_quant_band()`")
 
   data <- ggplot2::flip_data(data, flipped_aes)
 
@@ -233,22 +253,46 @@ quant_band_compute_group_fun <- function(data,
 
   grid <- data.frame(x = seq.indep)
 
-  # if method was specified as a character string, replace with
-  # the corresponding function
+  # If method was specified as a character string, replace with
+  # the corresponding function. Some model fit functions themselves have a
+  # method parameter accepting character strings as argument. We support
+  # these by splitting strings passed as argument at a colon.
   if (is.character(method)) {
-    if (identical(method, "rq")) {
-      method <- quantreg::rq
-    } else if (identical(method, "rqss")) {
-      method <- quantreg::rqss
-    } else {
-      method <- match.fun(method) # allow users to supply their own methods
+    if (method %in% c("br", "fn", "pfn", "sfn", "fnc", "conquer",
+                      "pfnb", "qfnb", "ppro", "lasso")) {
+      method <- paste("rq", method, sep = ":")
+      message("Using method: ", method)
     }
-  } else {
-    stopifnot(is.function(method))
+    method.name <- method
+    method <- strsplit(x = method, split = ":", fixed = TRUE)[[1]]
+    if (length(method) > 1L) {
+      fun.method <- method[2]
+      method <- method[1]
+    } else {
+      fun.method <- NULL
+    }
+    method <- switch(method,
+                     rq = quantreg::rq,
+                     rqss = quantreg::rqss,
+                     match.fun(method))
+  } else if (is.function(method)) {
+    fun.method <- method.args[["method"]]
+    if (is.name(quote(method))) {
+      method.name <- as.character(quote(method))
+    } else {
+      method.name <- "function"
+    }
+    if (length(fun.method)) {
+      method.name <- paste(method.name, fun.method, sep = ":")
+    }
+  }
+
+  if (length(fun.method)) {
+    method.args[["method"]] <- fun.method
   }
 
   z.ls <- lapply(sort(quantiles), quant_pred, data = data, method = method,
-                 formula = formula, weight = data$weight, grid = grid,
+                 formula = formula, weight = data[["weight"]], grid = grid,
                  method.args = method.args, orientation = "x",
                  make.groups = FALSE)
   z <- z.ls[[2]]
@@ -257,6 +301,11 @@ quant_band_compute_group_fun <- function(data,
   z[["ymax"]] <- z.ls[[3]][["y"]]
   z[["quantile.ymax"]] <- z.ls[[3]][["quantile"]]
 
+  if (fm.values) {
+    z[["n"]] <- nrow(na.omit(data[, c("x", "y")]))
+    z[["method"]] <- method.name
+  }
+
   z[["flipped_aes"]] <- flipped_aes
   ggplot2::flip_data(z, flipped_aes)
 }
