@@ -70,7 +70,7 @@
 #' @param orientation character Either "x" or "y" controlling the default for
 #'   \code{formula}.
 #' @param se logical Passed to \code{quantreg::predict.rq()}.
-#' @param mf.values logical Add n as a column to returned data? (`FALSE` by
+#' @param fm.values logical Add n as a column to returned data? (`FALSE` by
 #'   default.)
 #' @param level numeric in range [0..1] Passed to \code{quantreg::predict.rq()}.
 #' @param type character Passed to \code{quantreg::predict.rq()}.
@@ -95,7 +95,7 @@
 #'   interval around the mean} \item{ymax *or* xmax}{upper confidence
 #'   interval around the mean}}
 #'
-#'   If \code{mf.values = TRUE} is passed then one column with the number of
+#'   If \code{fm.values = TRUE} is passed then one column with the number of
 #'   observations \code{n} used for each fit is also included, with the same
 #'   value in each row within a group. This is wasteful and disabled by default,
 #'   but provides a simple and robust approach to achieve effects like colouring
@@ -199,7 +199,7 @@
 #'     stat_quant_line(geom = "debug")
 #'
 #'   ggplot(mpg, aes(displ, hwy)) +
-#'     stat_quant_line(geom = "debug", mf.values = TRUE)
+#'     stat_quant_line(geom = "debug", fm.values = TRUE)
 #'
 ##' }
 #'
@@ -213,7 +213,7 @@ stat_quant_line <- function(mapping = NULL,
                             quantiles = c(0.25, 0.5, 0.75),
                             formula = NULL,
                             se = length(quantiles) == 1L,
-                            mf.values = FALSE,
+                            fm.values = FALSE,
                             n = 80,
                             method = "rq",
                             method.args = list(),
@@ -274,7 +274,7 @@ stat_quant_line <- function(mapping = NULL,
       quantiles = quantiles,
       formula = formula,
       se = se,
-      mf.values = mf.values,
+      fm.values = fm.values,
       n = n,
       method = method,
       method.args = method.args,
@@ -307,7 +307,7 @@ quant_line_compute_group_fun <- function(data,
                                          type = "none",
                                          interval = "none",
                                          se = TRUE,
-                                         mf.values = FALSE,
+                                         fm.values = FALSE,
                                          na.rm = FALSE,
                                          flipped_aes = NA) {
   rlang::check_installed("quantreg", reason = "for `stat_quant_line()`")
@@ -376,7 +376,7 @@ quant_line_compute_group_fun <- function(data,
     z[["ymin"]] <- z[["ymax"]] <- NA_real_
   }
 
-  if (mf.values) {
+  if (fm.values) {
       z[["n"]] <- nrow(na.omit(data[, c("x", "y")]))
       z[["method"]] <- method.name
   }
