@@ -24,15 +24,59 @@ if (eval_broom_mixed) library(broom.mixed)
 ## -----------------------------------------------------------------------------
 old_theme <- theme_set(theme_bw())
 
+## -----------------------------------------------------------------------------
+set.seed(4321)
+x <- (1:100) / 10
+y <- x + rnorm(length(x))
+my.data <- data.frame(x = x,
+                      y = y,
+                      y.desc = - y,
+                      group = c("A", "B"))
+
+## -----------------------------------------------------------------------------
+ggplot(my.data, aes(x, y)) +
+  geom_point() +
+  stat_correlation()
+
+## -----------------------------------------------------------------------------
+ggplot(my.data, aes(x, y, color = group)) +
+  geom_point() +
+  stat_correlation()
+
+## -----------------------------------------------------------------------------
+ggplot(my.data, aes(x, y, color = group)) +
+  geom_point() +
+  stat_correlation(method = "spearman")
+
+## -----------------------------------------------------------------------------
+ggplot(my.data, aes(x, y, color = group)) +
+  geom_point() +
+  stat_correlation(mapping = use_label(c("R", "t", "P", "n")))
+
+## -----------------------------------------------------------------------------
+ggplot(my.data, aes(x, y)) +
+  geom_point() +
+  stat_correlation() +
+  facet_wrap(~group)
+
+## -----------------------------------------------------------------------------
+ggplot(my.data, aes(x, y)) +
+  geom_point() +
+  stat_correlation(mapping = aes(color = ifelse(after_stat(cor) > 0.955,
+                                                "red", "black"))) +
+  scale_color_identity() +
+  facet_wrap(~group)
+
 ## -----------------------------------------------------------------------------
 set.seed(4321)
 # generate artificial data
 x <- 1:100
 y <- (x + x^2 + x^3) + rnorm(length(x), mean = 0, sd = mean(x^3) / 4)
+y <- y / max(y)
 my.data <- data.frame(x, 
                       y, 
                       group = c("A", "B"), 
-                      y2 = y * c(0.5,2),
+                      y2 = y * c(1, 2) + c(0, 0.2),
                       block = c("a", "a", "b", "b"),
                       wt = sqrt(x))
 
@@ -48,26 +92,31 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(eq.label)), formula = formula)
+  stat_poly_eq(mapping = use_label("eq"), formula = formula)
 
 ## -----------------------------------------------------------------------------
 formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(adj.rr.label)), formula = formula) +
-  stat_poly_eq(aes(label = stat(AIC.label)),
-               label.x = "right", label.y = "bottom", size = 3,     
+  stat_poly_eq(mapping = aes(label = after_stat(eq.label)), 
                formula = formula)
 
+## -----------------------------------------------------------------------------
+formula <- y ~ poly(x, 3, raw = TRUE)
+ggplot(my.data, aes(x, y)) +
+  geom_point() +
+  stat_poly_line(formula = formula) +
+  stat_poly_eq(mapping = use_label("adj.R2"), formula = formula) +
+  stat_poly_eq(mapping = use_label("AIC"), label.x = "right", label.y = "bottom", size = 3,
+               formula = formula)
 
 ## -----------------------------------------------------------------------------
 formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label =  paste(stat(eq.label), stat(adj.rr.label), 
-                                  sep = "*\", \"*")),
+  stat_poly_eq(mapping = use_label(c("eq", "adj.R2")),
                formula = formula) +
   labs(x = expression(italic(x)), y = expression(italic(y)))
 
@@ -76,10 +125,10 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label =  paste(stat(eq.label), "*\" with \"*", 
-                                  stat(rr.label), "*\", \"*", 
-                                  stat(f.value.label), "*\", and \"*",
-                                  stat(p.value.label), "*\".\"",
+  stat_poly_eq(aes(label =  paste(after_stat(eq.label), "*\" with \"*", 
+                                  after_stat(rr.label), "*\", \"*", 
+                                  after_stat(f.value.label), "*\", and \"*",
+                                  after_stat(p.value.label), "*\".\"",
                                   sep = "")),
                formula = formula, size = 3)
 
@@ -88,8 +137,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label =  paste(stat(eq.label), stat(adj.rr.label), 
-                                  sep = "~~italic(\"with\")~~")),
+  stat_poly_eq(mapping = use_label(c("eq", "adj.R2"), sep = "~~italic(\"with\")~~"),
                formula = formula)
 
 ## ---- eval=eval_flag----------------------------------------------------------
@@ -97,7 +145,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = paste("atop(", stat(AIC.label), ",", stat(BIC.label), ")", sep = "")), 
+  stat_poly_eq(aes(label = paste("atop(", after_stat(AIC.label), ",", after_stat(BIC.label), ")", sep = "")), 
                formula = formula)
 
 ## ---- eval=eval_flag----------------------------------------------------------
@@ -105,7 +153,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(eq.label)),
+  stat_poly_eq(mapping = use_label("eq"),
                eq.with.lhs = FALSE,
                formula = formula)
 
@@ -114,7 +162,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(eq.label)),
+  stat_poly_eq(mapping = use_label("eq"),
                eq.with.lhs = "italic(hat(y))~`=`~",
                formula = formula)
 
@@ -123,7 +171,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(eq.label)),
+  stat_poly_eq(mapping = use_label(c("eq", "R2")),
                eq.with.lhs = "italic(h)~`=`~",
                eq.x.rhs = "~italic(z)",
                formula = formula) +
@@ -134,7 +182,7 @@ formula <- y ~ poly(x, 2, raw = TRUE)
 ggplot(my.data, aes(x, log10(y + 1e6))) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(eq.label)),
+  stat_poly_eq(mapping = use_label("eq"),
                eq.with.lhs = "plain(log)[10](italic(delta)+10^6)~`=`~",
                eq.x.rhs = "~Omega",
                formula = formula) +
@@ -145,33 +193,53 @@ formula <- y ~ poly(x, 5, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(eq.label)), formula = formula)
+  stat_poly_eq(mapping = use_label("eq"), formula = formula)
 
 ## ---- eval=eval_flag----------------------------------------------------------
 formula <- y ~ x + I(x^2) + I(x^3) - 1
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(eq.label)), formula = formula)
+  stat_poly_eq(aes(label = after_stat(eq.label)), formula = formula)
 
 ## -----------------------------------------------------------------------------
 formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label =  ifelse(stat(adj.r.squared > 0.3),
-                                   paste(stat(eq.label), stat(adj.rr.label), 
+  stat_poly_eq(aes(label =  ifelse(after_stat(adj.r.squared > 0.3),
+                                   paste(after_stat(eq.label), after_stat(adj.rr.label), 
                                          sep = "*\", \"*"),
-                                   stat(adj.rr.label))),
+                                   after_stat(adj.rr.label))),
                formula = formula) +
   labs(x = expression(italic(x)), y = expression(italic(y)))
 
+## -----------------------------------------------------------------------------
+poly_or_mean <- function(formula, data, ...) {
+   mf <- lm(formula = formula, data = data, ...)
+   if (anova(mf)[["Pr(>F)"]][1] > 0.1) {
+      lm(formula = y ~ 1, data = data, ...)
+   } else {
+      mf
+   }
+}
+
+## -----------------------------------------------------------------------------
+ggplot(mpg, aes(displ, hwy)) +
+   geom_point() +
+   stat_poly_line(method = "poly_or_mean") +
+   stat_poly_eq(method = poly_or_mean,
+   aes(label = after_stat(eq.label)),
+   label.x = "right") +
+   theme(legend.position = "bottom") +
+   facet_wrap(~class, ncol = 2)
+
 ## -----------------------------------------------------------------------------
 formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y2)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(eq.label)), size = 3,
+  stat_poly_eq(aes(label = after_stat(eq.label)), size = 3,
                formula = formula) +
   facet_wrap(~group)
 
@@ -180,7 +248,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y2)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(eq.label)), size = 3,
+  stat_poly_eq(aes(label = after_stat(eq.label)), size = 3,
                formula = formula) +
   facet_wrap(~group, scales = "free_y")
 
@@ -189,14 +257,14 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y2, colour = group)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(eq.label)), formula = formula, vstep = 0.06)
+  stat_poly_eq(aes(label = after_stat(eq.label)), formula = formula, vstep = 0.06)
 
 ## ---- eval=eval_flag----------------------------------------------------------
 formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y2, colour = group, grp.label = group)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(paste("bold(", grp.label, "*\":\")~~", 
+  stat_poly_eq(aes(label = after_stat(paste("bold(", grp.label, "*\":\")~~", 
                                       eq.label, sep = ""))),
                formula = formula)
 
@@ -205,7 +273,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y2, linetype = group, grp.label = group)) +
   geom_point() +
   stat_poly_line(formula = formula, color = "black") +
-  stat_poly_eq(aes(label = stat(paste("bold(", grp.label, "*':')~~~", 
+  stat_poly_eq(aes(label = after_stat(paste("bold(", grp.label, "*':')~~~", 
                                       eq.label, sep = ""))),
                formula = formula)
 
@@ -214,7 +282,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y2, colour = group)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(eq.label)),
+  stat_poly_eq(aes(label = after_stat(eq.label)),
                formula = formula,
                label.x = "centre")
 
@@ -223,7 +291,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y2, fill = block)) +
   geom_point(shape = 21, size = 3) +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(rr.label)), size = 3,
+  stat_poly_eq(aes(label = after_stat(rr.label)), size = 3,
                geom = "label_npc", alpha = 0.33,
                formula = formula) +
   facet_wrap(~group, scales = "free_y")
@@ -233,7 +301,7 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y2, colour = group, fill = block)) +
   geom_point(shape = 21, size = 3) +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(aes(label = stat(rr.label)), size = 3, alpha = 0.2,
+  stat_poly_eq(aes(label = after_stat(rr.label)), size = 3, alpha = 0.2,
                geom = "label_npc", label.y = c(0.95, 0.85, 0.95, 0.85),
                formula = formula) +
   facet_wrap(~group, scales = "free_y")
@@ -243,32 +311,32 @@ formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y2, colour = group)) +
   geom_point() +
   stat_poly_line(formula = formula) +
-  stat_poly_eq(geom = "text", aes(label = stat(eq.label)),
-               label.x = c(100, 90), label.y = c(-1e4, 2.1e6), hjust = "inward",
+  stat_poly_eq(geom = "text", aes(label = after_stat(eq.label)),
+               label.x = c(100, 20), label.y = c(-0.1, 2.1), hjust = "inward",
                formula = formula)
 
 ## -----------------------------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_poly_line(formula = y ~ x, color = "blue") +
-  stat_poly_eq(aes(label = stat(eq.label)), color = "blue") +
+  stat_poly_eq(mapping = use_label(c("R2", "eq")), color = "blue") +
   stat_poly_line(formula = y ~ x, color = "red", orientation = "y") +
-  stat_poly_eq(aes(label = stat(eq.label)), color = "red", orientation = "y",
+  stat_poly_eq(mapping = use_label(c("R2", "eq")), color = "red", orientation = "y",
                label.y = 0.9)
 
 ## -----------------------------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_ma_line() +
-  stat_ma_eq(aes(label = stat(eq.label)))
+  stat_ma_eq(mapping = use_label("eq"))
 
 ## -----------------------------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_ma_line(color = "blue") +
-  stat_ma_eq(aes(label = stat(eq.label)), color = "blue") +
+  stat_ma_eq(mapping = use_label(c("R2", "eq")), color = "blue") +
   stat_ma_line(color = "red", orientation = "y") +
-  stat_ma_eq(aes(label = stat(eq.label)), color = "red", orientation = "y",
+  stat_ma_eq(mapping = use_label(c("R2", "eq")), color = "red", orientation = "y",
              label.y = 0.9)
 
 ## ---- warning=FALSE-----------------------------------------------------------
@@ -279,7 +347,7 @@ ggplot(my.data, aes(x, y)) +
 ## ---- warning=FALSE-----------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
   geom_point() +
-  stat_quant_line(formula = y ~ poly(x, 2), quantiles = c(0.1, 0.9))
+  stat_quant_line(formula = y ~ poly(x, 2), quantiles = c(0.05, 0.95))
 
 ## ---- warning=FALSE-----------------------------------------------------------
 ggplot(my.data, aes(x, y)) +
@@ -290,8 +358,8 @@ ggplot(my.data, aes(x, y)) +
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_quant_band(formula = formula, color = "black", fill = "grey60") +
-  stat_quant_eq(aes(label = paste(stat(grp.label), "*\": \"*",
-                                  stat(eq.label), sep = "")),
+  stat_quant_eq(aes(label = paste(after_stat(grp.label), "*\": \"*",
+                                  after_stat(eq.label), sep = "")),
                 formula = formula) +
   theme_classic()
 
@@ -299,8 +367,8 @@ ggplot(my.data, aes(x, y)) +
 ggplot(my.data, aes(x, y, color = group)) +
   geom_point() +
   stat_quant_line(formula = formula) +
-  stat_quant_eq(aes(label = paste(stat(grp.label), "*\": \"*",
-                                  stat(eq.label), sep = "")),
+  stat_quant_eq(aes(label = paste(after_stat(grp.label), "*\": \"*",
+                                  after_stat(eq.label), sep = "")),
                formula = formula)
 
 ## ---- warning=FALSE-----------------------------------------------------------
@@ -308,8 +376,8 @@ ggplot(my.data, aes(x, y, group = group, linetype = group,
                     shape = group, grp.label = group)) +
   geom_point() +
   stat_quantile(formula = formula, color = "black") +
-  stat_quant_eq(aes(label = paste(stat(grp.label), "*\": \"*",
-                                  stat(eq.label), sep = "")),
+  stat_quant_eq(aes(label = paste(after_stat(grp.label), "*\": \"*",
+                                  after_stat(eq.label), sep = "")),
                 formula = formula, quantiles = c(0.05, 0.95)) +
   theme_classic()
 
@@ -317,10 +385,10 @@ ggplot(my.data, aes(x, y, group = group, linetype = group,
 ggplot(my.data, aes(x, y)) +
   geom_point() +
   stat_quant_line(formula = y ~ x, color = "blue", quantiles = 0.05) +
-  stat_quant_eq(aes(label = stat(eq.label)), formula = y ~ x, color = "blue",
+  stat_quant_eq(mapping = use_label("eq"), formula = y ~ x, color = "blue",
                 quantiles = 0.05) +
   stat_quant_line(formula = x ~ y, color = "red", quantiles = 0.95) +
-  stat_quant_eq(aes(label = stat(eq.label)), formula = x ~ y, color = "red", 
+  stat_quant_eq(mapping = use_label("eq"), formula = x ~ y, color = "red", 
                 quantiles = 0.95, label.y = 0.9)
 
 ## -----------------------------------------------------------------------------
@@ -329,6 +397,21 @@ ggplot(my.data, aes(x, y, colour = group)) +
   geom_hline(yintercept = 0, linetype = "dashed") +
   stat_fit_residuals(formula = formula)
 
+## -----------------------------------------------------------------------------
+formula <- y ~ poly(x, 3, raw = TRUE)
+ggplot(my.data, aes(x, y, colour = group)) +
+  geom_hline(yintercept = 0, linetype = "dashed") +
+  stat_fit_residuals(formula = formula,
+                     method = "rlm",
+                     mapping = aes(size = sqrt(after_stat(weights))),
+                     alpha = 2/3)
+
+## ---- eval = FALSE------------------------------------------------------------
+#  formula <- y ~ poly(x, 3, raw = TRUE)
+#  ggplot(my.data, aes(x, y, colour = group)) +
+#    geom_hline(yintercept = 0, linetype = "dashed") +
+#    stat_fit_residuals(formula = formula, weighted = TRUE)
+
 ## -----------------------------------------------------------------------------
 formula <- y ~ poly(x, 3, raw = TRUE)
 ggplot(my.data, aes(x, y)) +
@@ -367,9 +450,8 @@ ggplot(my.data, aes(x, y, colour = group)) +
                   method.args = list(formula = formula),
                   label.x = "right",
                   label.y = "bottom",
-                  aes(label = paste("italic(P)*\"-value = \"*", 
-                                    signif(stat(p.value), digits = 4),
-                                    sep = "")),
+                  aes(label = sprintf("italic(P)*\"-value = \"*%.3g", 
+                                      after_stat(p.value))),
                   parse = TRUE)
 
 ## -----------------------------------------------------------------------------
@@ -381,115 +463,11 @@ ggplot(Puromycin, aes(conc, rate, colour = state)) +
               se = FALSE) +
   stat_fit_glance(method = "nls", 
                   method.args = list(formula = micmen.formula),
-                  aes(label = paste("AIC = ", signif(stat(AIC), digits = 3), 
-                                    ", BIC = ", signif(stat(BIC), digits = 3),
+                  aes(label = paste("AIC = ", signif(after_stat(AIC), digits = 3), 
+                                    ", BIC = ", signif(after_stat(BIC), digits = 3),
                                     sep = "")),
                   label.x = "centre", label.y = "bottom")
 
-## -----------------------------------------------------------------------------
-micmen.formula <- y ~ SSmicmen(x, Vm, K) 
-ggplot(Puromycin, aes(conc, rate, colour = state)) +
-  geom_point() +
-  geom_smooth(method = "nls", 
-              formula = micmen.formula,
-              se = FALSE) +
-  stat_fit_tidy(method = "nls", 
-                method.args = list(formula = micmen.formula),
-                label.x = "right",
-                label.y = "bottom",
-                aes(label = paste("V[m]~`=`~", signif(stat(Vm_estimate), digits = 3),
-                                  "%+-%", signif(stat(Vm_se), digits = 2),
-                                  "~~~~K~`=`~", signif(stat(K_estimate), digits = 3),
-                                  "%+-%", signif(stat(K_se), digits = 2),
-                                  sep = "")),
-                parse = TRUE)
-
-## -----------------------------------------------------------------------------
-micmen.formula <- y ~ SSmicmen(x, Vm, K) 
-ggplot(Puromycin, aes(conc, rate, colour = state)) +
-  geom_point() +
-  geom_smooth(method = "nls", 
-              formula = micmen.formula,
-              se = FALSE) +
-  stat_fit_tidy(method = "nls", 
-                method.args = list(formula = micmen.formula),
-                size = 3,
-                label.x = "center",
-                label.y = "bottom",
-                vstep = 0.12,
-                aes(label = paste("V~`=`~frac(", signif(stat(Vm_estimate), digits = 2), "~C,",
-                                  signif(stat(K_estimate), digits = 2), "+C)",
-                                  sep = "")),
-                parse = TRUE) +
-  labs(x = "C", y = "V")
-
-## -----------------------------------------------------------------------------
-stat_micmen_eq <- function(vstep = 0.12,
-                           size = 3,
-                           ...) {
-  stat_fit_tidy(method = "nls", 
-                method.args = list(formula = micmen.formula),
-                aes(label = paste("V~`=`~frac(", signif(stat(Vm_estimate), digits = 2), "~C,",
-                                  signif(stat(K_estimate), digits = 2), "+C)",
-                                  sep = "")),
-                parse = TRUE,
-                vstep = vstep,
-                size = size,
-                ...)
-}
-
-## ---- eval=eval_flag----------------------------------------------------------
-micmen.formula <- y ~ SSmicmen(x, Vm, K) 
-ggplot(Puromycin, aes(conc, rate, colour = state)) +
-  geom_point() +
-  geom_smooth(method = "nls", 
-              formula = micmen.formula,
-              se = FALSE) +
-  stat_micmen_eq(label.x = "center",
-                label.y = "bottom") +
-  labs(x = "C", y = "V")
-
-## -----------------------------------------------------------------------------
-my_formula <- y ~ x
-
-ggplot(mpg, aes(displ, 1 / hwy)) +
-  geom_point() +
-  geom_quantile(quantiles = 0.5, formula = my_formula) +
-  stat_fit_tidy(method = "rq",
-                method.args = list(formula = y ~ x, tau = 0.5), 
-                tidy.args = list(se.type = "nid"),
-                mapping = aes(label = sprintf('y~"="~%.3g+%.3g~x*", with "*italic(P)~"="~%.3f',
-                                              after_stat(Intercept_estimate), 
-                                              after_stat(x_estimate),
-                                              after_stat(x_p.value))),
-                parse = TRUE)
-
-## -----------------------------------------------------------------------------
-stat_rq_eqn <- 
-  function(formula = y ~ x, 
-           tau = 0.5,
-           method = "br",
-           mapping = aes(label = sprintf('y~"="~%.3g+%.3g~x*", with "*italic(P)~"="~%.3f',
-                                         after_stat(Intercept_estimate), 
-                                         after_stat(x_estimate),
-                                         after_stat(x_p.value))),
-           parse = TRUE,
-           ...) {
-    method.args <- list(formula = formula, tau = tau, method = method)
-    stat_fit_tidy(method = "rq",
-                  method.args = method.args, 
-                  tidy.args = list(se.type = "nid"),
-                  mapping = mapping,
-                  parse = parse,
-                  ...)
-  }
-
-## ---- eval=eval_flag----------------------------------------------------------
-ggplot(mpg, aes(displ, 1 / hwy)) +
-  geom_point() +
-  geom_quantile(quantiles = 0.5, formula = my_formula) +
-  stat_rq_eqn(tau = 0.5, formula = my_formula)
-
 ## -----------------------------------------------------------------------------
 formula <- y ~ x + I(x^2) + I(x^3)
 ggplot(my.data, aes(x, y)) +
@@ -578,6 +556,110 @@ ggplot(chickwts, aes(factor(feed), weight)) +
   scale_x_discrete(expand = expansion(mult = c(0.1, 0.35))) +
   expand_limits(y = 0)
 
+## -----------------------------------------------------------------------------
+micmen.formula <- y ~ SSmicmen(x, Vm, K) 
+ggplot(Puromycin, aes(conc, rate, colour = state)) +
+  geom_point() +
+  geom_smooth(method = "nls", 
+              formula = micmen.formula,
+              se = FALSE) +
+  stat_fit_tidy(method = "nls", 
+                method.args = list(formula = micmen.formula),
+                label.x = "right",
+                label.y = "bottom",
+                aes(label = paste("V[m]~`=`~", signif(after_stat(Vm_estimate), digits = 3),
+                                  "%+-%", signif(after_stat(Vm_se), digits = 2),
+                                  "~~~~K~`=`~", signif(after_stat(K_estimate), digits = 3),
+                                  "%+-%", signif(after_stat(K_se), digits = 2),
+                                  sep = "")),
+                parse = TRUE)
+
+## -----------------------------------------------------------------------------
+micmen.formula <- y ~ SSmicmen(x, Vm, K) 
+ggplot(Puromycin, aes(conc, rate, colour = state)) +
+  geom_point() +
+  geom_smooth(method = "nls", 
+              formula = micmen.formula,
+              se = FALSE) +
+  stat_fit_tidy(method = "nls", 
+                method.args = list(formula = micmen.formula),
+                size = 3,
+                label.x = "center",
+                label.y = "bottom",
+                vstep = 0.12,
+                aes(label = paste("V~`=`~frac(", signif(after_stat(Vm_estimate), digits = 2), "~C,",
+                                  signif(after_stat(K_estimate), digits = 2), "+C)",
+                                  sep = "")),
+                parse = TRUE) +
+  labs(x = "C", y = "V")
+
+## -----------------------------------------------------------------------------
+stat_micmen_eq <- function(vstep = 0.12,
+                           size = 3,
+                           ...) {
+  stat_fit_tidy(method = "nls", 
+                method.args = list(formula = micmen.formula),
+                aes(label = paste("V~`=`~frac(", signif(after_stat(Vm_estimate), digits = 2), "~C,",
+                                  signif(after_stat(K_estimate), digits = 2), "+C)",
+                                  sep = "")),
+                parse = TRUE,
+                vstep = vstep,
+                size = size,
+                ...)
+}
+
+## ---- eval=eval_flag----------------------------------------------------------
+micmen.formula <- y ~ SSmicmen(x, Vm, K) 
+ggplot(Puromycin, aes(conc, rate, colour = state)) +
+  geom_point() +
+  geom_smooth(method = "nls", 
+              formula = micmen.formula,
+              se = FALSE) +
+  stat_micmen_eq(label.x = "center",
+                label.y = "bottom") +
+  labs(x = "C", y = "V")
+
+## -----------------------------------------------------------------------------
+my_formula <- y ~ x
+
+ggplot(mpg, aes(displ, 1 / hwy)) +
+  geom_point() +
+  geom_quantile(quantiles = 0.5, formula = my_formula) +
+  stat_fit_tidy(method = "rq",
+                method.args = list(formula = y ~ x, tau = 0.5), 
+                tidy.args = list(se.type = "nid"),
+                mapping = aes(label = sprintf('y~"="~%.3g+%.3g~x*", with "*italic(P)~"="~%.3f',
+                                              after_stat(Intercept_estimate), 
+                                              after_stat(x_estimate),
+                                              after_stat(x_p.value))),
+                parse = TRUE)
+
+## -----------------------------------------------------------------------------
+stat_rq_eqn <- 
+  function(formula = y ~ x, 
+           tau = 0.5,
+           method = "br",
+           mapping = aes(label = sprintf('y~"="~%.3g+%.3g~x*", with "*italic(P)~"="~%.3f',
+                                         after_stat(Intercept_estimate), 
+                                         after_stat(x_estimate),
+                                         after_stat(x_p.value))),
+           parse = TRUE,
+           ...) {
+    method.args <- list(formula = formula, tau = tau, method = method)
+    stat_fit_tidy(method = "rq",
+                  method.args = method.args, 
+                  tidy.args = list(se.type = "nid"),
+                  mapping = mapping,
+                  parse = parse,
+                  ...)
+  }
+
+## ---- eval=eval_flag----------------------------------------------------------
+ggplot(mpg, aes(displ, 1 / hwy)) +
+  geom_point() +
+  geom_quantile(quantiles = 0.5, formula = my_formula) +
+  stat_rq_eqn(tau = 0.5, formula = my_formula)
+
 ## -----------------------------------------------------------------------------
 # formula <- y ~ poly(x, 3, raw = TRUE)
 # broom::augment does not handle poly correctly!
